#ifndef DAEMON_H
#define DAEMON_H

#include <QObject>
#include <QDBusConnection>
#include <QDBusInterface>
#include <QDBusMessage>
#include <QFile>
#include <QFileSystemWatcher>
#include <QSettings>
#include <QStringList>
#include <QString>
#include <QTextStream>
#include <QTimer>
#include <QDateTime>

#define APP_VERSION "0.1.6"
#define BUS_NAME "com.nokia.csd.Call"
#define BUS_PATH "/com/nokia/csd/call"
#define INSTANCE_INTERFACE "com.nokia.csd.Call.Instance"
#define DEFAULT_WHITELIST "/home/user/MyDocs/whitelist.txt"
#define DEFAULT_BLACKLIST "/home/user/MyDocs/blacklist.txt"

class CallerXDaemon : public QObject
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.callerx.ifdbus")

public:

    explicit CallerXDaemon(QObject *parent = 0);
    ~CallerXDaemon();

    void Start();

signals:
    void quit();

public slots:
    Q_SCRIPTABLE void reload();
    Q_SCRIPTABLE void stop();
    Q_SCRIPTABLE void loadwhitelist();
    Q_SCRIPTABLE void loadblacklist();
    Q_SCRIPTABLE void addrecentnumber();
    Q_SCRIPTABLE QString ping();

private slots:
    void readSettings();
    void saveSettings();
    void initialize();
    void callScreen(const QDBusObjectPath&, const QString&);
    void callRelease(const QString&);
    void loadList();
    void updateList();
    void setLoadList(const QString&, bool m);
    void addToList(const QString&);
    bool isBlocked(const QString&);
    void logNumber();
    void sendSignal();

private:
    QFileSystemWatcher* fileWatcher;
    QStringList nList, callHistory;
    QString listPath, whitelistPath, blacklistPath, n, callPath, lastInNumber;
    bool whitelistMode, activeTimer, autoStart, isRunning, blockUnknown;
};
#endif // DAEMON_H
